DatabaseGeneralLib class

GeneralLib

Constructors

DatabaseGeneralLib()
GeneralLib

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

closeDatabaseMini({required String key}) → bool
GeneralLib
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openDatabaseMini({required String key, required DatabaseMiniGeneralLibraryBaseOptions databaseMiniGeneralLibraryBaseOptions, required Map defaultData}) → DatabaseMiniGeneralLibrary
GeneralLib
openDatabaseMiniAsync({required String key, required DatabaseMiniGeneralLibraryBaseOptions databaseMiniGeneralLibraryBaseOptions, required Map defaultData}) → Future<DatabaseMiniGeneralLibrary>
GeneralLib
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited