DatabaseMiniGeneralLibraryBaseAbstract class abstract

GeneralLib

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
platformName() → String
GeneralLib
readAsync() → Future<String>
GeneralLib
readSync() → String
GeneralLib
toString() → String
A string representation of this object.
inherited
writeAsync({required String content}) → Future<void>
GeneralLib
writeSync({required String content}) → void
GeneralLib

Operators

operator ==(Object other) → bool
The equality operator.
inherited