DatabaseMiniGeneralLibraryBaseOptions class

GeneralLib

Constructors

DatabaseMiniGeneralLibraryBaseOptions({required Crypto crypto, required bool isUseCrypto, required bool isIgnoreError})
GeneralLib

Properties

crypto → Crypto
GeneralLib
final
hashCode → int
The hash code for this object.
no setterinherited
isIgnoreError → bool
GeneralLib
final
isUseCrypto → bool
GeneralLib
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited