AnsiCode class final

Standard ANSI escape code for customizing terminal text output.

Properties

code → int
The numeric value associated with this code.
final
escape → String
Represents the value escaped for use in terminal output.
no setter
escapeForScript → String
Represents the value as an unescaped literal suitable for scripts.
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
A description of this code.
final
reset → AnsiCode?
The AnsiCode that resets this value, if one exists.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → AnsiCodeType
The type of code that is represented.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
wrap(String? value, {bool forScript = false}) → String?
Wraps value with the escape value for this code, followed by resetAll.

Operators

operator ==(Object other) → bool
The equality operator.
inherited