KeyStroke class

A representation of a keystroke.

Constructors

KeyStroke({String char = '', ControlCharacter controlChar = ControlCharacter.unknown})
A representation of a keystroke.
const
KeyStroke.char(String char)
A representation of a keystroke.
factory
KeyStroke.control(ControlCharacter controlChar)
A representation of a keystroke.
factory

Properties

char → String
The printable character.
final
controlChar → ControlCharacter
The control character value.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited