Hide class

GeneralLib

Constructors

Hide()
GeneralLib

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cloneRecuriveList({required List data, required List<HideRegExp> hideRegExps, bool ignoreError = false}) → List
GeneralLib
cloneRecuriveMap({required Map data, required List<HideRegExp> hideRegExps, bool ignoreError = false}) → Map
GeneralLib
hideData({required String data, required List<HideRegExp> hideRegExps, bool ignoreError = false}) → String
GeneralLib
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
obfocustData({required String mystring, int start = 5, int end = 5}) → String
GeneralLib
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

dataToOrigin<T>({required T data, required List<HideRegExp> hideRegExps, bool ignoreError = false}) → T
GeneralLib
dataToString({required dynamic data, required List<HideRegExp> hideRegExps, bool ignoreError = false}) → String
GeneralLib