HideRegExp class

GeneralLib

Constructors

HideRegExp({required RegExp regExp, required String replace, HideDataType hideDataType = HideDataType.replace, int startIndexObfuscate = 5, int endIndexObfuscate = 5})
GeneralLib

Properties

endIndexObfuscate → int
GeneralLib
final
hashCode → int
The hash code for this object.
no setterinherited
hideDataType → HideDataType
GeneralLib
final
regExp → RegExp
GeneralLib
final
replace → String
GeneralLib
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startIndexObfuscate → int
GeneralLib
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited