GeneralSocketData class

GeneralLib

Constructors

GeneralSocketData({required int port, required String socket_id, required String multiCastGroup})
GeneralLib

Properties

hashCode → int
The hash code for this object.
no setterinherited
is_initialized ↔ bool
GeneralLib
getter/setter pair
multiCastGroup → String
GeneralLib
final
port → int
GeneralLib
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
socket_id → String
GeneralLib
final

Methods

close() → bool
GeneralLib
ensureInitiaLized({required RawDatagramSocket socket, required NetworkInterface networkInterface, required FutureOr<void> onMessage(GeneralSocketMessageData generalSocketMessageData), required void onDone()}) → Future<void>
GeneralLib
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendJson({required Map value}) → int
GeneralLib
sendRaw({required List<int> buffer}) → int
GeneralLib
sendText({required String value}) → int
GeneralLib
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited