GeneralSocketMessageData class

GeneralLib

Constructors

GeneralSocketMessageData({required String socket_id, required String ipAddres, required Uint8List data})
GeneralLib

Properties

data → Uint8List
GeneralLib
final
hashCode → int
The hash code for this object.
no setterinherited
ipAddres → String
GeneralLib
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
socket_id → String
GeneralLib
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited