ScriptGeneratorStatus class

GeneralLib

Constructors

ScriptGeneratorStatus({required FileSystemEntity file_system_entity, required String text})
GeneralLib

Properties

file_system_entity ↔ FileSystemEntity
GeneralLib
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
GeneralLib
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited