ScriptGeneratorOptions class

GeneralLibrary

Constructors

ScriptGeneratorOptions({required String fileSystemEntityIgnore, required bool isVerbose})
GeneralLibrary

Properties

fileSystemEntityIgnore → String
GeneralLibrary
final
hashCode → int
The hash code for this object.
no setterinherited
isVerbose → bool
GeneralLibrary
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? fileSystemEntityIgnore, bool? isVerbose}) → ScriptGeneratorOptions
GeneralLibrary
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited