GeneralLibraryStream class

GeneralLib

Constructors

GeneralLibraryStream()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

generalLibraryCreateStreamController<T>({void onListen()?, void onPause()?, void onResume()?, FutureOr<void> onCancel()?, Duration delayDuration = Duration.zero, bool isSync = false, required GeneralLibraryStreamOnStreamControllerFunction<T> onStreamController}) → StreamController<T>
A controller with a stream that supports only one single subscriber.