TcpSocketClient class

GeneralLib

Implemented types

Constructors

TcpSocketClient({required dynamic host, required int port, dynamic sourceAddress, int sourcePort = 0, Duration? timeout, Map? connectData, Duration? pingInterval})
GeneralLib

Properties

connect_data ↔ Map
GeneralLib
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
host ↔ dynamic
GeneralLib
getter/setter pairoverride
isConnect ↔ bool
GeneralLib
getter/setter pairoverride
ping_interval ↔ Duration
GeneralLib
getter/setter pairoverride
port ↔ int
GeneralLib
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
socket ↔ Socket
GeneralLib
getter/setter pairoverride
sourceAddress ↔ dynamic
GeneralLib
getter/setter pairoverride
sourcePort ↔ int
GeneralLib
getter/setter pairoverride
timeout ↔ Duration?
GeneralLib
getter/setter pairoverride

Methods

connect({required FutureOr<void> onSocketData(Uint8List data), required FutureOr<void> onSocketConnection(SocketConnection socketConnection), Duration delayDuration = const Duration(milliseconds: 500)}) → Future<void>
GeneralLib
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send({required List<int> value, Duration durationTimeOut = const Duration(minutes: 1), Duration durationDelay = const Duration(milliseconds: 1)}) → Future<void>
GeneralLib
override
sendSync({required List<int> value, Duration durationTimeOut = const Duration(minutes: 1)}) → void
GeneralLib
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited